# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'spotii.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(480, 272)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setWindowTitle("MainWindow")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.title = QtWidgets.QWidget(self.centralwidget)
        self.title.setGeometry(QtCore.QRect(0, 0, 480, 49))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.title.sizePolicy().hasHeightForWidth())
        self.title.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(1)
        self.title.setFont(font)
        self.title.setStyleSheet("background-image: url(:/title_background/png/title/rectangle.png);")
        self.title.setInputMethodHints(QtCore.Qt.ImhNone)
        self.title.setObjectName("title")
        self.gridLayout = QtWidgets.QGridLayout(self.title)
        self.gridLayout.setContentsMargins(0, 0, 5, 0)
        self.gridLayout.setHorizontalSpacing(5)
        self.gridLayout.setObjectName("gridLayout")
        self.volume = MyToolButton(self.title)
        self.volume.setEnabled(True)
        self.volume.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.volume.setInputMethodHints(QtCore.Qt.ImhNone)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/sound/png/title/spot-icons-sound-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/sound/png/title/spot-icons-sound-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.volume.setIcon(icon)
        self.volume.setIconSize(QtCore.QSize(24, 18))
        self.volume.setCheckable(True)
        self.volume.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.volume.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.volume.setObjectName("volume")
        self.gridLayout.addWidget(self.volume, 0, 6, 1, 1)
        self.wifi = MyToolButton(self.title)
        self.wifi.setEnabled(True)
        self.wifi.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.wifi.setInputMethodHints(QtCore.Qt.ImhNone)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon1.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.wifi.setIcon(icon1)
        self.wifi.setIconSize(QtCore.QSize(24, 18))
        self.wifi.setCheckable(True)
        self.wifi.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.wifi.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.wifi.setObjectName("wifi")
        self.gridLayout.addWidget(self.wifi, 0, 4, 1, 1)
        self.logo = QtWidgets.QLabel(self.title)
        self.logo.setText("")
        self.logo.setPixmap(QtGui.QPixmap(":/logo/png/title/logo.png"))
        self.logo.setScaledContents(True)
        self.logo.setObjectName("logo")
        self.gridLayout.addWidget(self.logo, 0, 0, 1, 1)
        self.test_mode = QtWidgets.QToolButton(self.title)
        self.test_mode.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.test_mode.sizePolicy().hasHeightForWidth())
        self.test_mode.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(8)
        font.setBold(True)
        font.setWeight(75)
        font.setKerning(False)
        self.test_mode.setFont(font)
        self.test_mode.setStyleSheet("QToolButton{background-color: transparent; border:0; color : rgb(248,176,0)}")
        self.test_mode.setInputMethodHints(QtCore.Qt.ImhNone)
        self.test_mode.setIconSize(QtCore.QSize(24, 18))
        self.test_mode.setCheckable(True)
        self.test_mode.setChecked(False)
        self.test_mode.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.test_mode.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.test_mode.setObjectName("test_mode")
        self.gridLayout.addWidget(self.test_mode, 0, 10, 1, 1)
        self.help = MyToolButton(self.title)
        self.help.setEnabled(True)
        font = QtGui.QFont()
        font.setKerning(True)
        self.help.setFont(font)
        self.help.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.help.setInputMethodHints(QtCore.Qt.ImhNone)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/help/png/title/spot-icons-help-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon2.addPixmap(QtGui.QPixmap(":/help/png/title/spot-icons-help-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.help.setIcon(icon2)
        self.help.setIconSize(QtCore.QSize(24, 18))
        self.help.setCheckable(True)
        self.help.setPopupMode(QtWidgets.QToolButton.DelayedPopup)
        self.help.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.help.setObjectName("help")
        self.gridLayout.addWidget(self.help, 0, 3, 1, 1)
        self.chip_mode = QtWidgets.QLabel(self.title)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.chip_mode.sizePolicy().hasHeightForWidth())
        self.chip_mode.setSizePolicy(sizePolicy)
        self.chip_mode.setMinimumSize(QtCore.QSize(45, 0))
        font = QtGui.QFont()
        font.setFamily("Roboto")
        font.setPointSize(8)
        font.setBold(True)
        font.setWeight(75)
        self.chip_mode.setFont(font)
        self.chip_mode.setStyleSheet("QLabel{background-color: transparent; border:0; color : rgb(248,176,0)}")
        self.chip_mode.setAlignment(QtCore.Qt.AlignCenter)
        self.chip_mode.setWordWrap(True)
        self.chip_mode.setObjectName("chip_mode")
        self.gridLayout.addWidget(self.chip_mode, 0, 2, 1, 1)
        self.profile_icon = MyToolButton(self.title)
        self.profile_icon.setEnabled(True)
        self.profile_icon.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.profile_icon.setInputMethodHints(QtCore.Qt.ImhNone)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/profile/png/title/spot-icons-profile-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon3.addPixmap(QtGui.QPixmap(":/profile/png/title/spot-icons-profile-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.profile_icon.setIcon(icon3)
        self.profile_icon.setIconSize(QtCore.QSize(24, 18))
        self.profile_icon.setCheckable(True)
        self.profile_icon.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.profile_icon.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.profile_icon.setObjectName("profile_icon")
        self.gridLayout.addWidget(self.profile_icon, 0, 9, 1, 1)
        self.setting = MyToolButton(self.title)
        self.setting.setEnabled(True)
        self.setting.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        self.setting.setInputMethodHints(QtCore.Qt.ImhNone)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/setting/png/title/spot-icons-settings-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon4.addPixmap(QtGui.QPixmap(":/setting/png/title/spot-icons-settings-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.setting.setIcon(icon4)
        self.setting.setIconSize(QtCore.QSize(24, 18))
        self.setting.setCheckable(True)
        self.setting.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.setting.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.setting.setObjectName("setting")
        self.gridLayout.addWidget(self.setting, 0, 8, 1, 1)
        self.time_label = QtWidgets.QLabel(self.title)
        font = QtGui.QFont()
        font.setFamily("Roboto Black")
        font.setPointSize(14)
        self.time_label.setFont(font)
        self.time_label.setStyleSheet(".QLabel{background-color: transparent; border:0; color :white}")
        self.time_label.setObjectName("time_label")
        self.gridLayout.addWidget(self.time_label, 0, 1, 1, 1)
        self.slot_1 = MyStackedWidget(self.centralwidget)
        self.slot_1.setGeometry(QtCore.QRect(0, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_1.sizePolicy().hasHeightForWidth())
        self.slot_1.setSizePolicy(sizePolicy)
        self.slot_1.setStyleSheet("")
        self.slot_1.setObjectName("slot_1")
        self.slot_2 = MyStackedWidget(self.centralwidget)
        self.slot_2.setGeometry(QtCore.QRect(96, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_2.sizePolicy().hasHeightForWidth())
        self.slot_2.setSizePolicy(sizePolicy)
        self.slot_2.setStyleSheet("")
        self.slot_2.setObjectName("slot_2")
        self.slot_3 = MyStackedWidget(self.centralwidget)
        self.slot_3.setGeometry(QtCore.QRect(192, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_3.sizePolicy().hasHeightForWidth())
        self.slot_3.setSizePolicy(sizePolicy)
        self.slot_3.setStyleSheet("")
        self.slot_3.setObjectName("slot_3")
        self.slot_4 = MyStackedWidget(self.centralwidget)
        self.slot_4.setGeometry(QtCore.QRect(288, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_4.sizePolicy().hasHeightForWidth())
        self.slot_4.setSizePolicy(sizePolicy)
        self.slot_4.setStyleSheet("")
        self.slot_4.setObjectName("slot_4")
        self.slot_5 = MyStackedWidget(self.centralwidget)
        self.slot_5.setGeometry(QtCore.QRect(384, 49, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_5.sizePolicy().hasHeightForWidth())
        self.slot_5.setSizePolicy(sizePolicy)
        self.slot_5.setStyleSheet("")
        self.slot_5.setObjectName("slot_5")
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.slot_1.setCurrentIndex(-1)
        self.slot_2.setCurrentIndex(-1)
        self.slot_3.setCurrentIndex(-1)
        self.slot_4.setCurrentIndex(-1)
        self.slot_5.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        self.test_mode.setText(_translate("MainWindow", "SPEED"))
        self.chip_mode.setText(_translate("MainWindow", "AUTO MODE"))
        self.time_label.setText(_translate("MainWindow", "00:00"))
from MyStackedWidget import MyStackedWidget
from MyToolButton import MyToolButton
import title_rc



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi
import pytz
import time
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)

from define import *
import title_rc
from main_paras import getMainTopLeft
import main_paras



drop_down = 'QComboBox.drop-down {\
    subcontrol-origin: padding;\
    subcontrol-position: top right;\
    width: 60px;\
\
    border-left-width: 1px;\
    border-left-color: black;\
    border-left-style: solid; \
    border-top-right-radius: 3px; \
    border-bottom-right-radius: 3px;\
}'
class _TimeZone(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_TimeZone, self).__init__(parent)

        self.first = True
        loadUi(os.path.join(currentdir,'time_zone.ui'),self)
        self.config()
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
    def config(self):
        try:
            
            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)

            currentZone = main_paras.info.getTimeZone()
            if currentZone not in pytz.all_timezones:
                main_paras.info.setDefaultTimeZone()
                currentZone = main_paras.info.getTimeZone()

            self.time_zone_list.setStyleSheet("combobox-popup: 0;")
            self.time_zone_list.currentTextChanged.connect(self.on_time_zone_changed)
            self.time_zone_list.view().setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
            
            self.time_zone_list.addItems(pytz.all_timezones)
##            current = main_paras.info.getCurrentLanguage()
##            print(current)
            self.first = True
            self.time_zone_list.setCurrentIndex(self.time_zone_list.findText(currentZone));
            main_paras.info.setTimeZone(currentZone)
            #self.on_time_zone_changed()
            #drop_down
            #self.time_zone_list.setMaxVisibleItems(10)
            
            pass
        except Exception as error:
            print(error)
            


    def save_bt_hook(self):
        try:
##            main_paras.info.setCurrentLanguage(self.language.currentIndex())
##            self.close()
##            main_paras.queueForGui.put([LANGUAGE_CHANGE_INDEX, 0, '', '', ''])
            
            pass
                
        except Exception as error:
            print(error)

    def on_time_zone_changed(self):
        try:
            if self.first:
                self.first = False;
                return
            current = str(self.time_zone_list.currentText())
            main_paras.info.setTimeZone(current)
#             print ('Before: ', time.strftime('%X %x %Z'))
#             current = str(self.time_zone_list.currentText())
#             os.environ['TZ'] = current
#             main_paras.info.setTimeZone(current)
#             if sys.platform == 'linux':
#                 time.tzset()
#             print ('After: ', time.strftime('%X %x %Z'))
#             pass
                
        except Exception as error:
            print(error)
            
##>>> time.strftime('%X %x %Z')
##'12:45:20 08/19/09 CDT'
##>>> os.environ['TZ'] = 'Europe/London'
##>>> time.tzset()
##>>> time.strftime('%X %x %Z')
            

if __name__ == "__main__":    
    app = QtWidgets.QApplication(sys.argv)
    QtWidgets.QMainWindow
    window=_TimeZone()
    window.show()    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)


##QComboBox{
##background-image: url(:/public/png/public/rectangle-copy.png);
##background-color: transparent; 
##border:0; 
##color :white; 
##selection-color:black;
##selection-background-color:white;
##combobox-popup: 0;
##
##drop-down {
##    subcontrol-origin: padding;
##    subcontrol-position: top right;
##    width: 15px;
##
##    border-left-width: 1px;
##    border-left-color: black;
##    border-left-style: solid; /* just a single line */
##    border-top-right-radius: 3px; /* same radius as the QComboBox */
##    border-bottom-right-radius: 3px;
##};
##
##}



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.uic import loadUi

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)
grandparentdir =  os.path.dirname(parentdir)
sys.path.insert(0, grandparentdir)
g_g_parentdir = os.path.dirname(grandparentdir)
sys.path.insert(0, g_g_parentdir)

from define import *
import title_rc
from main_paras import getMainTopLeft
import main_paras



drop_down = 'QComboBox.drop-down {\
    subcontrol-origin: padding;\
    subcontrol-position: top right;\
    width: 60px;\
\
    border-left-width: 1px;\
    border-left-color: black;\
    border-left-style: solid; \
    border-top-right-radius: 3px; \
    border-bottom-right-radius: 3px;\
}'
class _Language(QtWidgets.QDialog):
    def __init__(self,parent=None):
        super(_Language, self).__init__(parent)


        loadUi(os.path.join(currentdir,'language.ui'),self)
        self.config()
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.Popup)
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
    def config(self):
        try:
            
            self.back.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.back.clicked.connect(self.close)
            self.save_bt.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
            self.save_bt.clicked.connect(self.save_bt_hook)

#            self.language.currentIndexChanged.connect(self.language_changed)
#            self.language.setStyleSheet(drop_down)
            self.language.view().setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
            self.language.addItems(main_paras.info.getLanguageList())
            current = main_paras.info.getCurrentLanguage()
            print(current)
            self.language.setCurrentIndex(self.language.findText(current));
            #drop_down
#            self.language.setMaxVisibleItems(4)
            pass
        except Exception as error:
            print(error)
            

    def save_bt_hook(self):
        try:
            main_paras.info.setCurrentLanguage(self.language.currentIndex())
            self.close()
            main_paras.queueForGui.put([LANGUAGE_CHANGE_INDEX, 0, '', '', ''])
            
            pass
                
        except Exception as error:
            print(error)

    def language_changed(self):
        try:
            print('language changed')
            pass
                
        except Exception as error:
            print(error)
            
            

if __name__ == "__main__":    
    app = QtWidgets.QApplication(sys.argv)
    QtWidgets.QMainWindow
    window=_Language()
    window.show()    
    rtn= app.exec_()
    print('main app return', rtn)
    sys.exit(rtn)


##QComboBox{
##background-image: url(:/public/png/public/rectangle-copy.png);
##background-color: transparent; 
##border:0; 
##color :white; 
##selection-color:black;
##selection-background-color:white;
##combobox-popup: 0;
##
##drop-down {
##    subcontrol-origin: padding;
##    subcontrol-position: top right;
##    width: 15px;
##
##    border-left-width: 1px;
##    border-left-color: black;
##    border-left-style: solid; /* just a single line */
##    border-top-right-radius: 3px; /* same radius as the QComboBox */
##    border-bottom-right-radius: 3px;
##};
##
##}



from main_paras import info

def addTest(user):
    pf = info.getProfile('feng.gao@laipac.com')
    pf['user']= user
    info.setProfile(pf)
    info.show()
    

if __name__ == "__main__":

##    addTest('hh_1')
##    addTest('hh_2')
##    addTest('hh_3')
##    addTest('hh_4')
##    addTest('hh_5')
##    addTest('hh_6')
##    addTest('hh_7')
##    addTest('hh_8')
##    addTest('hh_9')
##
##    info.clear()
    info.show()

 
##    pf=info.getProfile('feng.gao@laipac.com')
##
##    print('got', pf)
##
##    pf['user']='feng.gao@laipac.com'
##
##    print('modified', pf)
##              
##    print('get again', info.getProfile('aa'))



import os
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.QtCore import QTranslator

from PyQt5.uic import loadUi
import pathlib
import queue
import time
import subprocess

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
parentdir = os.path.dirname(currentdir)

sys.path.insert(0, parentdir)
sys.path.insert(0, currentdir)

from MyToolButton import MyToolButton
from MyStackedWidget import MyStackedWidget
import title_rc
from profile_folder.profile_wrap import _ProfileDialog
from help_folder.help_wrap import  _HelpDialog
from setting_folder.setting_wrap import _SettingDialog
from wifi_folder.wifi_list import _WifiList
from wifi_folder import wifi_setting
from volume.volume import _Volume
from define import *
from main_paras import setMainTopLeft, getMainTopLeft, mainChannelStart, setDetectionMode, getDetectionMode, setTestMode, getTestMode, queueForGui
import main_paras
from wrong_password import _WrongPassword
from vkeyboard import handleVisibleChanged
if sys.platform == 'linux':
    from  on_off.mainboard_pio import fanTurnOn
    #from  on_off.mainbaord_pio import hub_reset
currentPath=pathlib.Path(__file__).parent.absolute()




class EmitThread(QtCore.QThread):
    signal= QtCore.pyqtSignal(object)
    def __init__(self, sharedQue):
        QtCore.QThread.__init__(self)
        self.qForGui=sharedQue
    def run(self):
        print("Start emit thread")
        while True:
            try:
                qItem=self.qForGui.get()
                print('in gui', qItem)
                self.signal.emit(qItem)
                self.qForGui.task_done()
            except Exception as e:
                 print(e)
        
class MainWindow(QtWidgets.QMainWindow):
    def __init__(self,parent=None, qForGui=None):
        super(MainWindow, self).__init__(parent)
        self.trans=QTranslator()
#        QtWidgets.QApplication.instance().removeTranslator(trans)
        print( main_paras.info.show())
        print('language: ', main_paras.info.getCurrentLanguage())        
        language_qm = os.path.join(parentdir,main_paras.defaultLanguageFolder,main_paras.info.getCurrentLanguage(),'lng.qm')
        #language_qm = os.path.join(parentdir,"en-jp.qm")
        #print(language_qm)
        self.trans.load(language_qm)
        QtWidgets.QApplication.instance().installTranslator(self.trans)

        
        emitThread = EmitThread(qForGui)
        emitThread.signal.connect(self.emitHook)
        emitThread.start()
#        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.WindowStaysOnTopHint)
        flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint)
        self.setWindowFlags(flags)
        loadUi(os.path.join(currentPath,'spotii.ui'),self)
        self.tempPolling = QtCore.QTimer()
        self.tempPolling.timeout.connect(self.tempMonitor)
        self.time = QtCore.QTimer()
        self.time.timeout.connect(self.showTime)

        self.currentWifi = '__lp_ls2_nothing__'

        self.page=0
        self.slots = []
        self.allIcons = []
        main_paras.setAllDefault()
        self.config()
        self.show()
        
        
    def tempMonitor(self):

        self.wifiChecking()
        if sys.platform == 'linux':
            try:
                result=subprocess.check_output(['vcgencmd','measure_temp']).decode("utf-8")
                tmp=int(float(result.split('=')[1].split('\'')[0]))
                #print(tmp)
                fanTurnOn(False)
                if tmp > TEMP_ON_VALUE:
                    fanTurnOn(True)
                elif tmp < TEMP_OFF_VALUE:
                    fanTurnOn(False)
                
            except Exception as error:
                print(error)
                
    def showTime(self):
        try:
            
##            # getting current time
##            current_time = QtCore.QTime.currentTime()
##      
##            # converting QTime object to string
##            label_time = current_time.toString('hh:mm')

            label_time = time.strftime('%H:%M')
      
            # showing it to the label
            self.time_label.setText(label_time)
            
        except Exception as error:
            print(error)
        
        
    def config(self):
        try:
            slot_no = 0
            self.slots = self.findChildren(QtWidgets.QStackedWidget)
            for each in self.slots:
                each.setCurrentIndex(0)
                each.setSlotNo(slot_no)
                slot_no+=1
#                self.slots.append(Ui_Slot(slot))
                #self.slots.append(slot)

            
            self.allIcons = self.title.findChildren(QtWidgets.QToolButton)
            for icon in self.allIcons:
                icon.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))

            
            self.test_mode.clicked.connect(self.test_mode_hook)
            
            self.test_mode.setText(self.tr('NORMAL'))


            #self.help.clicked.connect(self.helpHookForTest)
            
            mainChannelStart(self.mainChannelHook)
            #self.chip_mode.setText(self.tr(getDetectionMode()))
            QtCore.QTimer.singleShot(0, self.setupAferUi)

            self.wifiChecking()
            self.time.start(1000)
            self.tempPolling.start(10000)
            
            if sys.platform == 'linux':
                try:
                    result=subprocess.check_output(['chmod','777','/home/pi/app/spotii/profile.json']).decode("utf-8")
                    
                except Exception as error:
                    print(error)
            
            
        except Exception as error:
            print(error)

    def wifiChecking(self):
        wifi_ssid = wifi_setting.wifiSsid()
        #print('ssid: ',wifi_ssid)
        if  self.currentWifi != wifi_ssid:
            icon = QtGui.QIcon()
            if wifi_ssid == None:
                main_paras.setWifiStatus(False)
                print('set to invalid')
                icon.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-invalid.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
                icon.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-invalid.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
            else:
                main_paras.setWifiStatus(True)
                print('set to normal')
                icon.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
                icon.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
            self.wifi.setIcon(icon)
            self.wifi.repaint()
            self.currentWifi = wifi_ssid
        
    def test_mode_hook(self):
        try:
            if not self.test_mode.isChecked():
                self.test_mode.setText(self.tr('NORMAL'))
                setTestMode(TEST_MODE_NORMAL)
            else:
                self.test_mode.setText(self.tr('SPEED'))
                setTestMode(TEST_MODE_SPEED)
        except Exception as e:
            print(e)

    def mainChannelHook(self,item):
        try:
            print('main Channel', item)
            if   item == MAIN_PARA_CASSETTE_TYPE_CHIP:
                self.chip_mode.setText(self.tr('AUTO MODE'))
                setDetectionMode(CASSETTE_DETECTION_MODE_AUTO)
                for each in self.slots:
                    each.setStatus(SLOT_STATUS_EMPTY, '')
            elif item == MAIN_PARA_CASSETTE_TYPE_QR:
                self.chip_mode.setText(self.tr('MANUAL MODE'))
                setDetectionMode(CASSETTE_DETECTION_MODE_MANUAL)
                for each in self.slots:
                    each.setStatus(SLOT_STATUS_SCAN, '')
        except Exception as e:
            print(e)

    def quitHook(self):
        print('will quit')
        #QtWidgets.qApp.quit()
        self.close()


    def setupAferUi(self):
        try:
            x = self.geometry().x()
            y = self.geometry().y()
            print('main x, y', x, y)
            setMainTopLeft(x, y)
            
            main_x, main_y =getMainTopLeft()
            self.help.setup(_HelpDialog, main_x, main_y)
            self.wifi.setup(_WifiList, main_x+205, main_y-7)
            self.volume.setup(_Volume, main_x+255, main_y-7)
            self.setting.setup(_SettingDialog, main_x+313, main_y-7)
            self.profile_icon.setup(_ProfileDialog, main_x+345, main_y-7)

##            self.wifi.setup(_WifiList, main_x+225, main_y-7)
##            self.volume.setup(_Volume, main_x+275, main_y-7)
##            self.setting.setup(_SettingDialog, main_x+325, main_y-7)
##            self.profile_icon.setup(_ProfileDialog, main_x+357, main_y-7)
            
        except Exception as e:
            print(e)
        
    def helpHookForTest(self):
        try:
            print('help test')

            self.page= (self.page+1) %self.slots[0].totalPage()
            for index in range(0,5):                
                self.slots[index].setStatus(self.page,'La0456789')
        except Exception as e:
            print(e)

    
    def emitHook(self,item):
        try:
            print(time.strftime('%Y%m%d%H%M%S'),"emitHook:",item)
            slotNo  = item[0]
            errCode = item[1]
            qrCode  = item[2]
            global popUp
            if slotNo == SIGN_IN_FIRST_INDEX:
                
                popUp = _WrongPassword()
                popUp.setMessage(self.tr("Sign in and enter basic test information."),self.tr('Ok'))
                x,y = getMainTopLeft()
                popUp.move(x,y)
                popUp.show()

##            elif slotNo == CHECK_NETWORK_INDEX:
##                
##                popUp = _WrongPassword()
##                popUp.setMessage(self.tr("Check network."),self.tr('Try again'))
##                x,y = getMainTopLeft()
##                popUp.move(x,y)
##                popUp.show()

            elif slotNo == LANGUAGE_CHANGE_INDEX:
                print('LANGUAGE_CHANGE_INDEX')
                self.language_change()
                
            elif slotNo == WIFI_CHECKING_INDEX:
                print('WIFI_CHECKING_INDEX')
                self.wifiChecking()
                
            elif slotNo == NON_SLOT_INDEX:
                for i in range(TOTAL_SLOTS):
                    self.slots[i].setStatus(SLOT_STATUS_WARNING, 'Checking...')
            elif errCode == DEVICE_STATE_TAKING_PHOTO:
                self.slots[item[0]].detecting_(qrCode)
                
            elif errCode == DEVICE_STATE_MANUAL_SCAN:
                self.slots[item[0]].setStatus(SLOT_STATUS_SCAN, qrCode)
            elif errCode == DEVICE_STATE_MANUAL_FLIP:
                self.slots[item[0]].setStatus(SLOT_STATUS_FLIP, qrCode)
            elif errCode == DEVICE_STATE_MANUAL_INVALID_QR:
                self.slots[item[0]].setStatus(SLOT_STATUS_INVALID_QR, qrCode)
            elif errCode == Positive_test_result:
                self.slots[item[0]].setStatus(SLOT_STATUS_POSITIVE, qrCode)
            elif errCode == Negative_test_result:
                self.slots[item[0]].setStatus(SLOT_STATUS_NEGATIVE, qrCode)
            elif errCode == Invalid_image_identifier:
                self.slots[item[0]].setStatus(SLOT_STATUS_INVALID, qrCode)
            elif errCode == DEVICE_STATE_CASSETTE_EMPTY:
                self.slots[item[0]].setStatus(SLOT_STATUS_EMPTY, qrCode)
            else:
                self.slots[item[0]].setStatus(SLOT_STATUS_WARNING, qrCode)
        except Exception as e:
            print('emitHook',e)
        
    def closeEvent(self,event):
        self.tempPolling.stop()
        if sys.platform == 'linux':
            fanTurnOn(False)
        
        print("Main window is closing")

    def language_change(self):

##        QtWidgets.QApplication.instance().removeTranslator(self.trans)
##        trans.load(os.path.join(parentdir,"en-zh-cn.qm"))
##        QtWidgets.QApplication.instance().installTranslator(trans)
        self.close()
        self.__init__(qForGui = queueForGui)
        print('main gui repaint done')
        
        
    
if __name__ == "__main__":
    import sys

    ##main_paras.languageInit()
    
    print(QtWidgets.qApp)
#     if(QtWidgets.qApp.focusWindow().isModal()):
#         pass
#            qGuiApp->focusWindow()->setModality(Qt::WindowModal);
    os.environ["QT_IM_MODULE"] = "qtvirtualkeyboard"

    
#    trans=QTranslator()
#    trans.load(os.path.join(parentdir,"en.qm"))
#    trans.load(os.path.join(parentdir,"en-jp.qm"))
    
    app = QtWidgets.QApplication(sys.argv)
    QtGui.QGuiApplication.inputMethod().visibleChanged.connect(handleVisibleChanged)
#    app.installTranslator(trans)
    
    window=MainWindow(qForGui = queueForGui)
    rtn= app.exec_()
    print('main app return', rtn)
    window.close()
    sys.exit(rtn)



import subprocess
import threading

import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
#sys.path.insert(0, currentdir)
parentdir = os.path.dirname(currentdir)
sys.path.insert(0, parentdir)

from define import *
import main_paras

class OffLineDetectionThread (threading.Thread):
    def __init__(self, threadID, name):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name

    def run (self):
        print('OffLineDetectionThread')
        while True:
            print('polling start')
            image=main_paras.queueForOffLine.get()
            print('from off line queue ',image)
            if image == CLOSE_NOW:
                break;
            ls=image.split('_')
            resultForGui = [int(ls[2]), int(ls[0]), ls[1], 'Off line test', 0 ]
            main_paras.queueForGui.put(resultForGui)
            main_paras.queueForOffLine.task_done()
            
if __name__ == "__main__":
    off_line_detection  = OffLineDetectionThread(4,"OnOff")

    off_line_detection.start()



import time
import json
from operator import itemgetter
import sys, os, inspect
currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))

import main_paras
from define import *

if sys.platform == 'linux':
    PROFILE_FOLDER = '/home/pi/app/spotii'
else:
    PROFILE_FOLDER = currentdir

DEFAULT_LANGUAGE = 'English'

##profile = {
##    'user': 'feng.gao@laipac.com',
##    'place': 'office',
##    'city': 'Markham',
##    'country': 'Canada',
##    'provider':	'Laipac'    
##    }



basic = {
    'language': DEFAULT_LANGUAGE,
    'time_zone':''
    }


class Config():
    def __init__(self):
        print('working folder', PROFILE_FOLDER)
        self.languageList = os.listdir(os.path.join(currentdir, main_paras.defaultLanguageFolder))        
        self.profile_list = {
            'basic': basic,
            'person': [],
            }
        if time.daylight:
            offsetHour = time.altzone / 3600
        else:
            offsetHour = time.timezone / 3600
        self.profile_list['basic']['time_zone'] = 'Etc/GMT%+d' % offsetHour        

        try:
            with open(os.path.join(PROFILE_FOLDER,'profile.json'), 'r') as infile:
                self.profile_list = json.load(infile)
                if self.profile_list['basic']['language'] not in self.languageList:
                    self.profile_list['basic']['language'] = DEFAULT_LANGUAGE
##                if self.profile_list['person'] !=[]:
##                    if self.profile_list['person']['user'] == '':
##                        self.profile_list['person'].clear()
        except Exception as e:
            print(e)

        print ('init Before: ', time.strftime('%X %x %Z'))
        os.environ['TZ'] = self.profile_list['basic']['time_zone']
        if sys.platform == 'linux':
            time.tzset()
        print ('init After: ', time.strftime('%X %x %Z'))
            
        
    def save(self):
        with open(os.path.join(PROFILE_FOLDER,'profile.json'), 'w+') as fp:
            json.dump(self.profile_list, fp, sort_keys=True, indent=4)
    def setCurrentLanguage(self,index):
        self.profile_list['basic']['language']=self.languageList[index]
        self.save()

    def getLanguageList(self):
        return self.languageList

    def getCurrentLanguage(self):
        return self.profile_list['basic']['language']

    def setDefaultTimeZone(self):
        if time.daylight:
            offsetHour = time.altzone / 3600
        else:
            offsetHour = time.timezone / 3600
        self.profile_list['basic']['time_zone'] = 'Etc/GMT%+d' % offsetHour        
        self.save()
        
    def setTimeZone(self, timeZone):
        self.profile_list['basic']['time_zone']=timeZone
        print ('Before: ', time.strftime('%X %x %Z'))
        os.environ['TZ'] = timeZone
        if sys.platform == 'linux':
            time.tzset()
        print ('After: ', time.strftime('%X %x %Z'))
        self.save()

    def getTimeZone(self):
        return self.profile_list['basic']['time_zone']
        
    def getProfile(self, user):
        profile = main_paras.empty.copy()
        for person in self.profile_list['person']:
            if user == person['user']:
                for key in profile:
                    if key in person.keys():
                        profile[key] = person[key]
                break;
        return profile

    def lastUser(self):
        if len(self.profile_list['person']) == 0:
            return ''
        return self.profile_list['person'][-1]['user']

    def saveUser(self,user):
        for i, person in enumerate(self.profile_list['person']):
            if user == person['user']:
                return;
        profile = main_paras.empty.copy()
        profile['user']=user
        self.profile_list['person'].append(profile)
        self.save()
    
    
    def setProfile(self, profile):
        delete_out = len(self.profile_list['person']) - MAX_PROFILES
        if delete_out>0:
            del self.profile_list['person'][0:delete_out]
        for i, person in enumerate(self.profile_list['person']):
            if profile['user'] == person['user']:
                del self.profile_list['person'][i]
                break;
        else:
            del self.profile_list['person'][0]
            
        self.profile_list['person'].append(profile)
        self.save()

    def clear(self):
        self.profile_list = {
            'basic': basic,
            'person': [],
            }
        self.save()

    def show(self):
        print(self.profile_list)
        
        
   



##    print(profile)
##    with open('profile.json', 'w') as fp:
##        json.dump(profile, fp, sort_keys=True, indent=4)
##    
##    with open('profile.json', 'r') as infile:
##        data = json.load(infile)
##    print('from file',data)
##          


    
if __name__ == "__main__":
    pass              
